"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SubscriptionCronService = void 0;
const cron = require("node-cron");
const common_1 = require("@nestjs/common");
const mongoose_1 = require("@nestjs/mongoose");
const mongoose_2 = require("mongoose");
const payment_schema_1 = require("./script/schema/payment.schema");
const moment = require("moment");
const request = require("request");
let SubscriptionCronService = class SubscriptionCronService {
    constructor(paymentModel) {
        this.paymentModel = paymentModel;
    }
    startCronJob() {
        cron.schedule('* * * * *', async () => {
            console.log('Running subscription validation cron job...');
            const today = moment();
            try {
                const activeSubscriptions = await this.paymentModel.find({
                    status: true,
                });
                if (!activeSubscriptions.length) {
                    console.log('No subscriptions to validate.');
                    return;
                }
                let isExpire = !activeSubscriptions.some((payment) => moment(payment.ExpireDate).isAfter(today));
                if (isExpire === false) {
                    for (let index = 0; index < activeSubscriptions.length; index++) {
                        const element = activeSubscriptions[index];
                        const receiptData = element['payment_token'];
                        const options = {
                            method: 'POST',
                            url: 'https://sandbox.itunes.apple.com/verifyReceipt',
                            headers: {
                                'Content-Type': 'application/json',
                            },
                            body: JSON.stringify({
                                'receipt-data': receiptData,
                                password: process?.env?.APPLE_SHARED_SECRET ||
                                    'bd63ae724a5f4c74b614ad8384704785',
                            }),
                        };
                        request(options, async (error, response) => {
                            if (error) {
                                console.error('Error during receipt verification:', error);
                                return;
                            }
                            try {
                                const parsedResponse = JSON.parse(response.body);
                                const isAutoRenewEnabled = Number(parsedResponse?.pending_renewal_info[0]?.auto_renew_status);
                                const expirationIntent = Number(parsedResponse?.pending_renewal_info[0]?.expiration_intent);
                                const userId = element?._id;
                                if (isAutoRenewEnabled === 0 && expirationIntent > 0) {
                                    await this.paymentModel.findByIdAndUpdate(userId, { ExpireDate: new Date(), status: false }, { new: true });
                                }
                            }
                            catch (parseError) {
                                console.error('Failed to parse response:', parseError);
                            }
                        });
                    }
                }
            }
            catch (error) {
                console.log(`Error running subscription validation cron job: ${error.message}`);
            }
        });
    }
};
exports.SubscriptionCronService = SubscriptionCronService;
exports.SubscriptionCronService = SubscriptionCronService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, mongoose_1.InjectModel)(payment_schema_1.Payment.name)),
    __metadata("design:paramtypes", [mongoose_2.Model])
], SubscriptionCronService);
//# sourceMappingURL=cron.js.map